aboutsummaryrefslogtreecommitdiffstats
path: root/epan/packet_info.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2002-10-31 07:12:42 +0000
committerGuy Harris <guy@alum.mit.edu>2002-10-31 07:12:42 +0000
commit56f644145e0a4299a10099738fb74e1a08cd6fbd (patch)
tree7e11961398633886725fb3b33b3a254666a04af2 /epan/packet_info.h
parent663bc2174e185804d1aa41c664a27ff6093a131d (diff)
Discard the WTAP_ENCAP_LAPD encapsulation type in favor of a
WTAP_ENCAP_ISDN encapsulation type, which includes a pseudo-header giving the direction (user-to-network or network-to-user) and the channel number. Add a new circuit type, using the ISDN channel number as the circuit ID. Add an ISDN dissector to put the direction and channel number into the protocol tree and to call the appropriate dissector for the payload based on the channel (LAPD for the D channel; V.120, PPP, or data for B channels, based on some heuristics). svn path=/trunk/; revision=6521
Diffstat (limited to 'epan/packet_info.h')
-rw-r--r--epan/packet_info.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/epan/packet_info.h b/epan/packet_info.h
index 50c62155b0..2bb6c9654b 100644
--- a/epan/packet_info.h
+++ b/epan/packet_info.h
@@ -1,7 +1,7 @@
/* packet_info.h
* Definitions for packet info structures and routines
*
- * $Id: packet_info.h,v 1.23 2002/10/22 08:22:07 guy Exp $
+ * $Id: packet_info.h,v 1.24 2002/10/31 07:12:38 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -102,7 +102,8 @@ typedef enum {
/* Types of circuit IDs Ethereal knows about. */
typedef enum {
CT_NONE, /* no port number */
- CT_DLCI /* Frame Relay DLCI */
+ CT_DLCI, /* Frame Relay DLCI */
+ CT_ISDN /* ISDN channel number */
/* Could also have X.25 logical channel and ATM VPI/VCI pairs */
} circuit_type;